@@ -1,22 +1,8 @@
 /*
  * This file is part of the KDE Milou Project
- * Copyright (C) 2019 Kai Uwe Broulik <kde@broulik.de>
+ * SPDX-FileCopyrightText: 2019 Kai Uwe Broulik <kde@broulik.de>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
 
@@ -181,19 +167,21 @@ QString RunnerResultsModel::queryString() const
     return m_queryString;
 }
 
-void RunnerResultsModel::setQueryString(const QString &queryString)
+void RunnerResultsModel::setQueryString(const QString &queryString, const QString &runner)
 {
-    if (m_queryString.trimmed() == queryString.trimmed()) {
+    // If our query and runner are the same we don't need to query again
+    if (m_queryString.trimmed() == queryString.trimmed() && m_prevRunner == runner) {
         return;
     }
 
+    m_prevRunner = runner;
     m_queryString = queryString;
     m_hasMatches = false;
     if (queryString.isEmpty()) {
         clear();
     } else if (!queryString.trimmed().isEmpty()) {
         m_resetTimer.start();
-        m_manager->launchQuery(queryString, m_runner);
+        m_manager->launchQuery(queryString, runner);
         setQuerying(true);
     }
     Q_EMIT queryStringChanged(queryString);
@@ -212,39 +200,6 @@ void RunnerResultsModel::setQuerying(bool querying)
     }
 }
 
-QString RunnerResultsModel::runner() const
-{
-    return m_runner;
-}
-
-void RunnerResultsModel::setRunner(const QString &runner)
-{
-    if (m_runner == runner) {
-        return;
-    }
-
-    m_runner = runner;
-    m_manager->setSingleModeRunnerId(runner);
-    m_manager->setSingleMode(!runner.isEmpty());
-    Q_EMIT runnerChanged();
-}
-
-QString RunnerResultsModel::runnerName() const
-{
-    if (auto *singleRunner = m_manager->singleModeRunner()) {
-        return singleRunner->name();
-    }
-    return QString();
-}
-
-QIcon RunnerResultsModel::runnerIcon() const
-{
-    if (auto *singleRunner = m_manager->singleModeRunner()) {
-        return singleRunner->icon();
-    }
-    return QIcon();
-}
-
 void RunnerResultsModel::clear()
 {
     m_manager->reset();
@@ -345,6 +300,8 @@ QVariant RunnerResultsModel::data(const QModelIndex &index, int role) const
             return match.matchCategory();
         case ResultsModel::SubtextRole:
             return match.subtext();
+        case ResultsModel::MultiLineRole:
+            return match.isMultiLine();
         case ResultsModel::ActionsRole: {
             const auto actions = m_manager->actionsForMatch(match);
             if (actions.isEmpty()) {
